document.addEventListener('DOMContentLoaded', () => {
  const themeToggle = document.getElementById('themeToggle');
  const projectGrid = document.querySelector('.project-grid');
  const modal = document.getElementById('projectModal');
  const searchInput = document.getElementById('projectSearch');
  const projectTemplate = document.getElementById('projectTemplate');

  // Theme Toggle
  themeToggle.addEventListener('click', () => {
    document.body.dataset.theme = document.body.dataset.theme === 'dark' ? 'light' : 'dark';
    localStorage.setItem('theme', document.body.dataset.theme);
  });

  // Load saved theme
  document.body.dataset.theme = localStorage.getItem('theme') || 'light';

  // Mock project data
  const projects = [
    {
      name: 'Linux',
      preview: 'data:image/svg+xml,<svg></svg>',
      description: 'The Linux kernel project',
      status: 'Active',
      donationUrl: 'https://www.linuxfoundation.org/donate',
      homepage: 'https://www.kernel.org'
    }
    // Add more projects here
  ];

  // Render projects
  function renderProjects(projectsToRender) {
    projectGrid.innerHTML = '';
    projectsToRender.forEach(project => {
      const clone = projectTemplate.content.cloneNode(true);
      clone.querySelector('.project-name').textContent = project.name;
      clone.querySelector('.project-preview').src = project.preview;
      clone.querySelector('.project-status').textContent = project.status;
      
      clone.querySelector('.project-tile').addEventListener('click', () => {
        showProjectModal(project);
      });
      
      projectGrid.appendChild(clone);
    });
  }

  // Search functionality
  searchInput.addEventListener('input', (e) => {
    const searchTerm = e.target.value.toLowerCase();
    const filtered = projects.filter(project => 
      project.name.toLowerCase().includes(searchTerm)
    );
    renderProjects(filtered);
  });

  // Modal handling
  function showProjectModal(project) {
    modal.querySelector('.modal-title').textContent = project.name;
    modal.querySelector('.modal-preview').src = project.preview;
    modal.querySelector('.project-description').textContent = project.description;
    modal.querySelector('.activity-status').textContent = `Status: ${project.status}`;
    
    modal.style.display = 'block';
  }

  modal.querySelector('.close-modal').addEventListener('click', () => {
    modal.style.display = 'none';
  });

  // Close modal on outside click
  window.addEventListener('click', (e) => {
    if (e.target === modal) {
      modal.style.display = 'none';
    }
  });

  // Initial render
  renderProjects(projects);
});